#include <OneWire.h>
#include <DallasTemperature.h>
#include <LiquidCrystal.h>
#include <Stepper.h>


#define ONE_WIRE_BUS 10
#define FullSteps 32
#define R360 2048 //32*64
#define R90 512


OneWire oneWire(ONE_WIRE_BUS);
DallasTemperature sensors(&oneWire);
Stepper AlarmMotor(FullSteps, 14, 16, 15, 17);
LiquidCrystal lcd(12, 11, 2, 3, 4, 5);


int deviceCount = 0;
const int buzzer = 8;
int ledLamp = 9;
int CurrentRotation = 0;

float Temp1;
float Temp2;
float Temp3;

//////////////////////////////////////////////////////////////////////////////

void setup()
{
  pinMode(buzzer, OUTPUT);
  pinMode(ledLamp, OUTPUT);

  pinMode(14, OUTPUT);
  pinMode(15, OUTPUT);
  pinMode(16, OUTPUT);
  pinMode(17, OUTPUT);

  //servoPrivod.attach(6);
  //servoPrivod.write(0);

  sensors.begin();
  lcd.begin(16, 2);
  deviceCount = sensors.getDeviceCount();

}

////////////////////////////////////////////////////////////////////

void loop()
{
  //---------------GET TEMPERATURE------------------------//
  sensors.requestTemperatures();
  Temp1 = sensors.getTempCByIndex(0);
  Temp2 = sensors.getTempCByIndex(1);
  Temp3 = sensors.getTempCByIndex(2);

  //---------------WRITE TEMPERATURE----------------------//

  lcd.clear();
  lcd.setCursor(0, 0);
  lcd.print("Temp: " + String(Temp1));
  lcd.setCursor(0, 1);
  lcd.print(String(Temp2) + " " + String(Temp3));

  //---------------CHECK FOR TROUBLE----------------------//

  if ((Temp1 > 31) || (Temp2 > 31) || (Temp3 > 31)) 
  {     
    //----------------BAD---------------//

    tone(buzzer , 294 , 100);     //---SET---//
    digitalWrite(ledLamp, HIGH);  //--ALARM--//
    

    //--SEND SIGNAL TO THE ROBOT--//
    AlarmMotor.setSpeed(512);
    if(CurrentRotation == 0)
    {
      if(Temp1 > 31)      CurrentRotation += R90;
      else if(Temp2 > 31) CurrentRotation += (R90 * 2);
      else if(Temp3 > 31) CurrentRotation += (R90 * 3); 
      AlarmMotor.step(CurrentRotation);
      delay(1000);
    }
    
  }
  else if(CurrentRotation > 0)  //-----------GOOD--------------//
  {
    //---REMOVE ALARM---//
    digitalWrite(ledLamp, LOW);   

    //--RESET ROTATION OF THE MOTOR--//
    AlarmMotor.setSpeed(256);
    AlarmMotor.step(-CurrentRotation);
    CurrentRotation = 0;
    delay(1000);
  }
}
